==> Java-Swing-0.03.tar.gz: Java-Swing-0.03/java/PerlTableColumnModelListener.java <==
import javax.swing.event.TableColumnModelListener;
import org.perl.inline.java.*;

public class      PerlTableColumnModelListener
       extends    InlineJavaPerlCaller
       implements TableColumnModelListener
{
    String sender;
    String callbacks;

    public PerlTableColumnModelListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void columnAdded(javax.swing.event.TableColumnModelEvent event)  {
        try {
            CallPerl(
                "Java::Swing::TableColumnModelListener",
                "_TableColumnModelListener",
                new Object[] {sender, callbacks, "columnAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnRemoved(javax.swing.event.TableColumnModelEvent event)  {
        try {
            CallPerl(
                "Java::Swing::TableColumnModelListener",
                "_TableColumnModelListener",
                new Object[] {sender, callbacks, "columnRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnMoved(javax.swing.event.TableColumnModelEvent event)  {
        try {
            CallPerl(
                "Java::Swing::TableColumnModelListener",
                "_TableColumnModelListener",
                new Object[] {sender, callbacks, "columnMoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnMarginChanged(javax.swing.event.ChangeEvent event)  {
        try {
            CallPerl(
                "Java::Swing::TableColumnModelListener",
                "_TableColumnModelListener",
                new Object[] {sender, callbacks, "columnMarginChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnSelectionChanged(javax.swing.event.ListSelectionEvent event)  {
        try {
            CallPerl(
                "Java::Swing::TableColumnModelListener",
                "_TableColumnModelListener",
                new Object[] {sender, callbacks, "columnSelectionChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.11.tar.gz: Java-Swing-0.11/java/PerlTableColumnModelListener.java <==
import javax.swing.event.TableColumnModelListener;
import org.perl.inline.java.*;

public class      PerlTableColumnModelListener
       extends    InlineJavaPerlCaller
       implements TableColumnModelListener
{
    String sender;
    String callbacks;

    public PerlTableColumnModelListener() throws InlineJavaException { }

    public PerlTableColumnModelListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void columnAdded(javax.swing.event.TableColumnModelEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "columnAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnRemoved(javax.swing.event.TableColumnModelEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "columnRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnMoved(javax.swing.event.TableColumnModelEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "columnMoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnMarginChanged(javax.swing.event.ChangeEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "columnMarginChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void columnSelectionChanged(javax.swing.event.ListSelectionEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "columnSelectionChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
